import { renderless, api } from '@opentinyvue/vue-renderless/filter-box/vue';
import { defineComponent, $prefix, setup, $props } from '@opentinyvue/vue-common';
import { iconDownWard, iconError, iconHelpCircle } from '@opentinyvue/vue-icon';
import Tooltip from '@opentinyvue/vue-tooltip';
import '@opentinyvue/vue-theme/filter-box/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script = defineComponent({
  name: $prefix + "FilterBox",
  emits: ["click", "handle-clear"],
  components: {
    IconDownWard: iconDownWard(),
    IconError: iconError(),
    IconHelpCircle: iconHelpCircle(),
    TinyTooltip: Tooltip
  },
  props: _extends({}, $props, {
    label: String,
    value: [String, Number],
    tip: String,
    placeholder: {
      type: String,
      default: ""
    },
    showClose: {
      type: Boolean,
      default: true
    },
    disabled: {
      type: Boolean,
      default: false
    },
    dropDownVisible: {
      type: Boolean,
      default: false
    },
    blank: {
      type: Boolean,
      default: false
    }
  }),
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["tiny-filter-box", _vm.disabled && "disabled", _vm.blank && "is-blank"],
    on: {
      "click": _vm.handeClick
    }
  }, [_c("p", {
    class: ["title", _vm.dropDownVisible && "active"]
  }, [_c("label", [_vm._v(_vm._s(_vm.label))]), _vm.tip ? _c("tiny-tooltip", {
    attrs: {
      "effect": "light",
      "content": _vm.tip,
      "placement": "top"
    }
  }, [_c("icon-help-circle")], 1) : _vm._e()], 1), _c("p", {
    staticClass: "value",
    class: ["value", !_vm.value && _vm.value !== 0 && "placeholder"]
  }, [_vm._v(" " + _vm._s(_vm.value || _vm.value === 0 ? _vm.value : _vm.placeholder) + " ")]), _vm.value && _vm.showClose && !_vm.disabled ? _c("icon-error", {
    staticClass: "filter-icon-close",
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.handleClear.apply(null, arguments);
      }
    }
  }) : _c(_vm.state.expandButtonIcon, {
    tag: "component",
    class: ["filter-box-icon", _vm.dropDownVisible && "is-reverse"]
  })], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var FilterBox = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.22.0";
FilterBox.install = function(Vue) {
  Vue.component(FilterBox.name, FilterBox);
};
FilterBox.version = version;

export { FilterBox as default };
